==> haystack-0.4.1.tar.gz: lib/src/HCol.dart <==
///
/// Copyright (c) 2015, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

part of haystack.hgrid;


/// HCol is a column in a HGrid.
///
/// See [Project Haystack](http://project-haystack.org/doc/Grids)
class HCol {

  /** Package private constructor */
  HCol(this._index, this._name, this._meta);


//////////////////////////////////////////////////////////////////////////
// Access
//////////////////////////////////////////////////////////////////////////

  /** Return programatic name of column */
  String get name => _name;

  int get index => _index;

  /** Return display name of column which is meta.dis or name */
  String get dis {
    HVal dis = _meta.get("dis", checked:false);
    return (dis is HStr) ? (dis as HStr).val : _name;
  }

  /** Column meta-data tags */
  HDict get meta => _meta;


//////////////////////////////////////////////////////////////////////////
// Identity
//////////////////////////////////////////////////////////////////////////

  /** Hash code is based on name and meta */
  int _hashCode;
  @override
  int get hashCode => (_hashCode != null) ? _hashCode : _hashCode = hash2(_name, _meta);

  /** Equality is name and meta */
  bool operator ==(Object that) => that is HCol && _name == that._name && _meta == that.meta;


//////////////////////////////////////////////////////////////////////////
// Fields
//////////////////////////////////////////////////////////////////////////

  final int _index;
  final String _name;
  final HDict _meta;

}

==> haystack-0.4.19.tar.gz: lib/src/HCol.dart <==
///
/// Copyright (c) 2015, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

part of haystack.hgrid;


/// HCol is a column in a HGrid.
///
/// See [Project Haystack](http://project-haystack.org/doc/Grids)
class HCol {

  /** Package private constructor */
  HCol(this._index, this._name, this._meta);


//////////////////////////////////////////////////////////////////////////
// Access
//////////////////////////////////////////////////////////////////////////

  /** Return programatic name of column */
  String get name => _name;

  int get index => _index;

  /** Return display name of column which is meta.dis or name */
  String get dis {
    HVal dis = _meta.get("dis", checked:false);
    return (dis is HStr) ? dis.val : _name;
  }

  /** Column meta-data tags */
  HDict get meta => _meta;


//////////////////////////////////////////////////////////////////////////
// Identity
//////////////////////////////////////////////////////////////////////////

  /** Hash code is based on name and meta */
  int _hashCode;
  @override
  int get hashCode => (_hashCode != null) ? _hashCode : _hashCode = hash2(_name, _meta);

  /** Equality is name and meta */
  bool operator ==(Object that) => that is HCol && _name == that._name && _meta == that.meta;


//////////////////////////////////////////////////////////////////////////
// Fields
//////////////////////////////////////////////////////////////////////////

  final int _index;
  final String _name;
  final HDict _meta;

}
